==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_ro_RO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished">&lt;bazat pe localizare&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Setări ceas LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished">Setări ceas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Oră</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>Afișează &amp;secundele</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Stil 12 de &amp;ore</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished">&amp;Utilizează UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished">&amp;Formatul datei</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished">&amp;Nu afișa data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished">Afișează data &amp;înaintea orei</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished">Afișează data &amp;după timp</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished">Afișează data pe un &amp;rând nou sub oră</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished">Prima zi a săptămânii</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished">Orientare</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished">Rotire automată când panoul e vertical</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Dată</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Afișează &amp;data</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Format d&amp;ată</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Afișează data pe rând &amp;nou</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished">Format de dată personalizat</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished">Secvențe interpretate pentru formatarea datei sunt:

d   numărul zilei fără zero în față  (între 1 și 31)
dd  numărul zilei cu zero în față (între 01 și 31)
ddd numele abreviat al zilei (de ex. &apos;Lu&apos; până &apos;Du&apos;).
dddd    numele lung al zilei (de ex. &apos;Luni&apos; până &apos;Duminică&apos;).
M   numărul lunii fără zero în față (1-12)
MM  numărul lunii cu zero în față (01-12)
MMM numele abreviat și localizat al lunii (de ex. &apos;Ian&apos; - &apos;Dec&apos;).
MMMM    numele lung și localizat al lunii (de ex. &apos;Ianuarie&apos; - &apos;December&apos;).
yy  anul ca un număr din 2 cifre (00-99)
yyyy    anul ca un număr din 4 cifre

Orice alt caracter introdus va fi tratat ca text.
Orice secvență de caractere intre ghilimele simple (&apos;)
vor fi la fel tratate ca text si nu vor fi interpretate in expresie.


Format de dată personalizat:</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_ro_RO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation type="unfinished">&lt;bazat pe localizare&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Setări ceas LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation type="unfinished">Setări ceas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Oră</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>Afișează &amp;secundele</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Stil 12 de &amp;ore</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation type="unfinished">&amp;Utilizează UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation type="unfinished">&amp;Formatul datei</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation type="unfinished">&amp;Nu afișa data</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation type="unfinished">Afișează data &amp;înaintea orei</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation type="unfinished">Afișează data &amp;după timp</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation type="unfinished">Afișează data pe un &amp;rând nou sub oră</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation type="unfinished">Prima zi a săptămânii</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation type="unfinished">Orientare</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation type="unfinished">Rotire automată când panoul e vertical</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Dată</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Afișează &amp;data</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Format d&amp;ată</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Afișează data pe rând &amp;nou</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation type="unfinished">Format de dată personalizat</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation type="unfinished">Secvențe interpretate pentru formatarea datei sunt:

d   numărul zilei fără zero în față  (între 1 și 31)
dd  numărul zilei cu zero în față (între 01 și 31)
ddd numele abreviat al zilei (de ex. &apos;Lu&apos; până &apos;Du&apos;).
dddd    numele lung al zilei (de ex. &apos;Luni&apos; până &apos;Duminică&apos;).
M   numărul lunii fără zero în față (1-12)
MM  numărul lunii cu zero în față (01-12)
MMM numele abreviat și localizat al lunii (de ex. &apos;Ian&apos; - &apos;Dec&apos;).
MMMM    numele lung și localizat al lunii (de ex. &apos;Ianuarie&apos; - &apos;December&apos;).
yy  anul ca un număr din 2 cifre (00-99)
yyyy    anul ca un număr din 4 cifre

Orice alt caracter introdus va fi tratat ca text.
Orice secvență de caractere intre ghilimele simple (&apos;)
vor fi la fel tratate ca text si nu vor fi interpretate in expresie.


Format de dată personalizat:</translation>
    </message>
</context>
</TS>
